```rst
HermesBaby
##########

** The software engineers' typewriter **
```

![ud_hermesbaby.puml](http://www.plantuml.com/plantuml/proxy?src=https://raw.githubusercontent.com/hermesbaby/hermesbaby/main/_figures/ud_hermesbaby.puml&fmt=svg)


```rst
Usage
*****

Quickstart
==========

.. code-block:: bash

    pipx install hermesbaby
    hermesbaby new MyNewProject
    cd MyNewProject
    hermesbaby preview
    # Start editing ./docs/index.rst ...
```


```rst
See what's possible
===================

.. code-block:: bash

    cd
    hermesbaby new SeeWhatsPossible --template showcase
    cd SeeWhatsPossible
    hermesbaby preview
    # Investigate preview in browser and sources in editor
```
